return {
  manufacturer = 'Illuxtron',
  description = 'FluxeBLE',
  default_name = 'FLBLE_0426A',
  skip_init_write = true,
  version = 2,
  objects = {
    { id = 'onoff', name = 'On/Off', datatype = dt.bool, write_only = true },
    { id = 'intensity', name = 'Intensity', datatype = dt.scale, write_only = true },
    { id = 'red', name = 'Red', channel = 0, datatype = dt.scale, write_only = true },
    { id = 'green', name = 'Green', channel = 1, datatype = dt.scale, write_only = true },
    { id = 'blue', name = 'Blue', channel = 2, datatype = dt.scale, write_only = true },
    { id = 'amber', name = 'Amber', channel = 3, datatype = dt.scale, write_only = true },
    { id = 'warmwhite', name = 'Warm white', channel = 4, datatype = dt.scale, write_only = true },
    { id = 'coolwhite', name = 'Cool white', channel = 5, datatype = dt.scale, write_only = true },
    { id = 'rgb', name = 'RGB', datatype = dt.rgb, write_only = true },
    { id = 'colortemp', name = 'Color temperature', datatype = dt.uint16, write_only = true },
  },
  write = function(device, object, value)
    local id, red, green, blue, amber, sock, channel, b1, b2, res

    sock = ble.sock()
    ble.settimeout(sock, 3)
    res = ble.connect(sock, device.mac, true)

    -- connect ok
    if res then
      id = object.id

      -- lamp on/off
      if id == 'onoff' then
        value = toboolean(value) and 1 or 0
        res = ble.sockwritecmd(sock, 0x000e, value)
      -- light intensity
      elseif id == 'intensity' then
        value = math.floor(value * 2.55)
        res = ble.sockwritecmd(sock, 0x0010, value)
      -- color control rgb -> rgba
      elseif id == 'rgb' then
        red = bit.band(bit.rshift(value, 16), 0xFF)
        green = bit.band(bit.rshift(value, 8), 0xFF)
        blue = bit.band(value, 0xFF)
        amber = math.floor((red + green * 0.749) * 0.572)

        -- rgb color components
        res = ble.sockwritecmd(sock, 0x0016, 0x04, 0x00, red, 0x01, green, 0x02, blue, 0x03, amber)
      -- while color temperature
      elseif id == 'colortemp' then
        b1 = bit.band(bit.rshift(value, 8), 0xFF)
        b2 = bit.band(value, 0xFF)
        res = ble.sockwritecmd(sock, 0x0012, b1, b2)
      -- single channel
      else
        -- find channel number based on object id
        for _, obj in ipairs(device.profile.objects) do
          if id == obj.id then
            channel = obj.channel
          end
        end

        if channel then
          value = math.floor(value * 2.55)
          res = ble.sockwritecmd(sock, 0x0016, 0x01, channel, value)
        end
      end

      -- disconnect request
      ble.sockwritecmd(sock, 0x0020, 0x01)
    end

    device.setactive(toboolean(res))
    ble.close(sock)
  end
}
