return {
  manufacturer = 'MIO',
  description = 'MIO Alpha',
  default_name = 'MIO GLOBAL',
  version = 1,
  objects = {
    {
      id = 'pulse',
      name = 'Pulse',
      datatype = dt.uint8
    }
  },
  step = function(device)
    local sock, res, data, err, delta

    sock = device.sock

    if not sock then
      sock = ble.sock()
      ble.settimeout(sock, 5)

      -- try connecting
      res = ble.connect(sock, device.mac, true)
      if not res then
        ble.close(sock)
        device.setactive(false)
        os.sleep(5)
        return
      end

      -- enable button notification
      ble.sockwritecmd(sock, 0x25, 1, 0)
      device.sock = sock
      device.pulse = 0
    end

    res, data = ble.sockreadnotify(sock, 5)
    -- read ok
    if res then
      data = data:byte(2)
      delta = math.abs(device.pulse - data)

      if delta > 2 then
        device.pulse = data
        device.writeobject('pulse', data)
      end

      device.setactive(true)
    -- timeout or disconnect
    else
      res, err = ble.check(sock)

      -- disconnect
      if not res or err ~= 0 then
        ble.close(sock)
        device.sock = nil
      end
    end
  end
}
