return {
  manufacturer = 'Xiaomi',
  description = 'Mi Band',
  default_name = 'MI',
  version = 2,
  objects = {
    {
      id = 'steps',
      name = 'Steps',
      datatype = dt.uint16
    },
    {
      id = 'battery',
      name = 'Battery level',
      datatype = dt.scale
    },
    {
      id = 'vibrate',
      name = 'Vibrate',
      datatype = dt.switch,
      write_only = true
    }
  },
  init = function(device)
    local objects = device.objects

    -- disable read function when sensors are not used
    if not objects.steps and not objects.battery then
      device.profile.read = nil
    end

    -- disable write function when vibrate is not used
    if not objects.vibrate then
      device.profile.write = nil
    end
  end,
  read = function(device)
    local sock, res, rsteps, rbattery, status, values, rssi

    sock = ble.sock()
    ble.settimeout(sock, 30)
    res = ble.connect(sock, device.mac)

    -- connect ok
    if res then
      rsteps = ble.sockreadhnd(sock, 0x1D) or ''
      rbattery = ble.sockreadhnd(sock, 0x2B) or ''

      rssi = ble.getrssi(device.mac)

      -- read ok
      if #rsteps == 2 and #rbattery == 10 then
        status = true
        values = {}

        values.steps = rsteps:byte(2) * 256 + rsteps:byte(1)
        values.battery = rbattery:byte(1)
      end
    end

    ble.close(sock)

    return status, values, rssi
  end,
  write = function(device, object, value)
    local sock

    if object.id ~= 'vibrate' or value ~= true then
      return
    end

    sock = ble.sock()
    ble.settimeout(sock, 30)
    res = ble.connect(sock, device.mac)

    if res then
      ble.sockwritecmd(sock, 0x4D, 0x01)
    end

    device.writeobject(object.id, false)

    ble.close(sock)
  end
}
